aboutsummaryrefslogtreecommitdiff
path: root/src/or/connection_or.c
diff options
context:
space:
mode:
authorRoger Dingledine <arma@torproject.org>2011-10-31 04:33:38 -0400
committerRoger Dingledine <arma@torproject.org>2011-10-31 04:33:38 -0400
commitbe1f3a5eb596730cbb321c525a92ceb0a8178128 (patch)
tree2a9c4b30e5212a64c00cf4d6d435612b91e753c0 /src/or/connection_or.c
parentc58f4a86521d3d222d60787d63f6040f73a4c054 (diff)
downloadtor-be1f3a5eb596730cbb321c525a92ceb0a8178128.tar
tor-be1f3a5eb596730cbb321c525a92ceb0a8178128.tar.gz
normalize the name of the CERTS cell
Diffstat (limited to 'src/or/connection_or.c')
-rw-r--r--src/or/connection_or.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/or/connection_or.c b/src/or/connection_or.c
index 202548a6b..684d3abd2 100644
--- a/src/or/connection_or.c
+++ b/src/or/connection_or.c
@@ -1435,7 +1435,7 @@ connection_or_check_valid_tls_handshake(or_connection_t *conn,
* side of <b>conn</b> is <b>peer_id</b>. For v1 and v2 handshakes,
* this is right after we get a certificate chain in a TLS handshake
* or renegotiation. For v3 handshakes, this is right after we get a
* certificate chain in a CERT cell.
*
* If we want any particular ID before, record the one we got.
*
@@ -1950,10 +1950,10 @@ connection_or_send_netinfo(or_connection_t *conn)
return 0;
}
/** Send a CERT cell on the connection <b>conn</b>. Return 0 on success, -1
* on failure. */
int
-connection_or_send_cert_cell(or_connection_t *conn)
+connection_or_send_certs_cell(or_connection_t *conn)
{
const tor_cert_t *link_cert = NULL, *id_cert = NULL;
const uint8_t *link_encoded = NULL, *id_encoded = NULL;
@@ -1977,7 +1977,7 @@ connection_or_send_cert_cell(or_connection_t *conn)
2 * ( 1 + 2 ) /* For each cert: 1 byte for type, 2 for length */ +
link_len + id_len;
cell = var_cell_new(cell_len);
- cell->command = CELL_CERT;
+ cell->command = CELL_CERTS;
cell->payload[0] = 2;
pos = 1;
@@ -1435,7 +1435,7 @@ connection_or_check_valid_tls_handshake(or_connection_t *conn,
* this is right after we get a certificate chain in a TLS handshake
* or renegotiation. For v3 handshakes, this is right after we get a
- * certificate chain in a CERT cell.
+ * certificate chain in a CERTS cell.
*
* If we want any particular ID before, record the one we got.
@@ -1950,10 +1950,10 @@ connection_or_send_netinfo(or_connection_t *conn)
return 0;
}
-/** Send a CERT cell on the connection <b>conn</b>. Return 0 on success, -1
+/** Send a CERTS cell on the connection <b>conn</b>. Return 0 on success, -1
* on failure. */
int